EXPORTS
	?TDllFn1@@YAHABVTDesC8@@@Z @ 1 NONAME ; int TDllFn1(class TDesC8 const &)
	?TDllFn2@@YAHABVTDesC8@@@Z @ 2 NONAME ; int TDllFn2(class TDesC8 const &)
	?TDllFn3@@YAHABVTDesC8@@@Z @ 3 NONAME ; int TDllFn3(class TDesC8 const &)
	?TDllFn4@@YAHABVTDesC8@@@Z @ 4 NONAME ; int TDllFn4(class TDesC8 const &)
	?TDllFn5@@YAHABVTDesC8@@@Z @ 5 NONAME ; int TDllFn5(class TDesC8 const &)
	?TDllFn6@@YAHABVTDesC8@@@Z @ 6 NONAME ; int TDllFn6(class TDesC8 const &)
	?TDllFn7@@YAHABVTDesC8@@@Z @ 7 NONAME ; int TDllFn7(class TDesC8 const &)
	?TDllFn8@@YAHABVTDesC8@@@Z @ 8 NONAME ; int TDllFn8(class TDesC8 const &)
	?TDllFn9@@YAHABVTDesC8@@@Z @ 9 NONAME ; int TDllFn9(class TDesC8 const &)
	?TDllFn10@@YAHABVTDesC8@@@Z @ 10 NONAME ; int TDllFn10(class TDesC8 const &)
	?TDllFn11@@YAHABVTDesC8@@@Z @ 11 NONAME ; int TDllFn11(class TDesC8 const &)
	?TDllFn12@@YAHABVTDesC8@@@Z @ 12 NONAME ; int TDllFn12(class TDesC8 const &)
	?TDllFn13@@YAHABVTDesC8@@@Z @ 13 NONAME ; int TDllFn13(class TDesC8 const &)
	?TDllFn14@@YAHABVTDesC8@@@Z @ 14 NONAME ; int TDllFn14(class TDesC8 const &)
	?TDllFn15@@YAHABVTDesC8@@@Z @ 15 NONAME ; int TDllFn15(class TDesC8 const &)
	?TDllFn16@@YAHABVTDesC8@@@Z @ 16 NONAME ; int TDllFn16(class TDesC8 const &)
	?TDllFn17@@YAHABVTDesC8@@@Z @ 17 NONAME ; int TDllFn17(class TDesC8 const &)
	?TDllFn18@@YAHABVTDesC8@@@Z @ 18 NONAME ; int TDllFn18(class TDesC8 const &)

